"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const firestore_1 = require("firebase-functions/v2/firestore");
const utils_1 = require("./utils");
const firestore_storage_core_1 = require("firestore-storage-core");
require("should");
const functionTest = require("firebase-functions-test");
describe('Functions', function () {
    const Users = new firestore_storage_core_1.CollectionPath('users', 'userId');
    const app = functionTest({
        projectId: 'demo-functions',
    });
    const path = Users.doc({ userId: 'u1' });
    // Make snapshot for state of database beforehand
    const beforeSnap = app.firestore.makeDocumentSnapshot({ foo: 'bar' }, path);
    // Make snapshot for state of database after the change
    const afterSnap = app.firestore.makeDocumentSnapshot({ foo: 'faz' }, path);
    it('should check return type of create function', async () => {
        const fn = (0, firestore_1.onDocumentCreated)(Users.path(), (event) => {
            return (0, utils_1.parseFirestoreCreate)(event, Users);
        });
        // Call wrapped function with the Change object
        const wrapped = app.wrap(fn);
        const result = wrapped(beforeSnap);
        result.should.properties('ids', 'data');
    });
    it('should check return type of update function', async () => {
        const fn = (0, firestore_1.onDocumentWritten)(Users.path(), (event) => {
            return (0, utils_1.parseFirestoreChange)(event, Users);
        });
        const change = app.makeChange(beforeSnap, afterSnap);
        // Call wrapped function with the Change object
        const wrapped = app.wrap(fn);
        const result = wrapped(change);
        result.should.properties('ids', 'before', 'after');
    });
});
//# sourceMappingURL=integration.test.js.map